@@ -3,7 +3,7 @@ import json
 from jinja2 import Environment, FileSystemLoader
 
 
-def write_tex(report_name: str, summary_path="tests/data/results.json"):
+def write_tex(report_name: str, summary_path=None):
     rendered_report = get_rendered_report(report_name, summary_path)
     with open(f"reports/{report_name}.tex", "w") as report_tex:
         report_tex.writelines(rendered_report)
@@ -24,8 +24,10 @@ def get_jinja_latex():
     return latex_jinja_env
 
 
-def get_rendered_report(report_name, path):
-    effort_summary = load_json(path)
+def get_rendered_report(report_name, path=None):
+    effort_summary = {}
+    if path is not None:
+        effort_summary = load_json(path)
     latex_jinja_env = get_jinja_latex()
     template = latex_jinja_env.get_template(f"reports/templates/{report_name}.tex")
     return template.render(effort_summary)
